@@ -10,7 +10,7 @@ CREATE TABLE `linkcat` (
   `orderno`     int(2) default '99',
   `category`    varchar(255) default NULL,
   PRIMARY KEY  (`catid`)
-) ENGINE=MyISAM DEFAULT CHARSET=latin1;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8;
 SET character_set_client = @saved_cs_client;
 
 --
@@ -20,9 +20,6 @@ SET character_set_client = @saved_cs_client;
 INSERT INTO `linkcat` VALUES (1,1,'Category 1');
 INSERT INTO `linkcat` VALUES (2,2,'Category 2');
 INSERT INTO `linkcat` VALUES (3,3,'Category 3');
-INSERT INTO `linkcat` VALUES (4,4,'Category 4');
-INSERT INTO `linkcat` VALUES (5,5,'Category 5');
-INSERT INTO `linkcat` VALUES (6,6,'Category 6');
 
 --
 -- Table structure for table `links`
@@ -38,16 +35,13 @@ CREATE TABLE `links` (
   `title`       varchar(255) NOT NULL default '',
   `body`        blob,
   PRIMARY KEY  (`linkid`)
-) ENGINE=MyISAM DEFAULT CHARSET=latin1;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8;
 SET character_set_client = @saved_cs_client;
 
 --
 -- Dumping data for table `links`
 --
 
-INSERT INTO `links` VALUES (1,1,'http://www.example.com','Example Link 1.',NULL);
-INSERT INTO `links` VALUES (2,2,'http://www.example.com','Example Link 2.',NULL);
-INSERT INTO `links` VALUES (3,3,'http://www.example.com','Example Link 3.',NULL);
-INSERT INTO `links` VALUES (4,4,'http://www.example.com','Example Link 4.',NULL);
-INSERT INTO `links` VALUES (5,5,'http://www.example.com','Example Link 5.',NULL);
-INSERT INTO `links` VALUES (6,6,'http://www.example.com','Example Link 6.',NULL);
+INSERT INTO `links` VALUES (1,1,'http://www.example.com','Example Link 1',NULL);
+INSERT INTO `links` VALUES (2,2,'http://www.example.com','Example Link 2',NULL);
+INSERT INTO `links` VALUES (3,3,'http://www.example.com','Example Link 3',NULL);
